@@ -20,6 +20,7 @@
 #include "breezemdiwindowshadow.h"
 
 #include "breeze.h"
+#include "breezeboxshadowrenderer.h"
 #include "breezeshadowhelper.h"
 #include "breezestyleconfigdata.h"
 
@@ -50,12 +51,21 @@ namespace Breeze
         const CompositeShadowParams params = ShadowHelper::lookupShadowParams( StyleConfigData::shadowSize() );
         if( params.isNone() ) return;
 
-        const int shadowSize = qMax( params.shadow1.radius, params.shadow2.radius );
-        const int size( shadowSize - Metrics::Shadow_Overlap );
-        const int topSize( size - params.offset.y() );
-        const int bottomSize( size + params.offset.y() );
-        const int leftSize( size - params.offset.x() );
-        const int rightSize( size + params.offset.x() );
+        const QSize boxSize = BoxShadowRenderer::calculateMinimumBoxSize(params.shadow1.radius)
+            .expandedTo(BoxShadowRenderer::calculateMinimumBoxSize(params.shadow2.radius));
+
+        const QSize shadowSize = BoxShadowRenderer::calculateMinimumShadowTextureSize(boxSize, params.shadow1.radius, params.shadow1.offset)
+            .expandedTo(BoxShadowRenderer::calculateMinimumShadowTextureSize(boxSize, params.shadow2.radius, params.shadow2.offset));
+
+        const QRect shadowRect(QPoint(0, 0), shadowSize);
+
+        QRect boxRect(QPoint(0, 0), boxSize);
+        boxRect.moveCenter(shadowRect.center());
+
+        const int topSize( boxRect.top() - shadowRect.top() - Metrics::Shadow_Overlap - params.offset.y() );
+        const int bottomSize( shadowRect.bottom() - boxRect.bottom() - Metrics::Shadow_Overlap + params.offset.y() );
+        const int leftSize( boxRect.left() - shadowRect.left() - Metrics::Shadow_Overlap - params.offset.x() );
+        const int rightSize( shadowRect.right() - boxRect.right() - Metrics::Shadow_Overlap + params.offset.x() );
 
         // get tileSet rect
         auto hole = _widget->frameGeometry();
